/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.auth.impl;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;
import org.opensaml.common.binding.BasicSAMLMessageContext;
import org.opensaml.saml2.binding.decoding.HTTPPostDecoder;
import org.opensaml.ws.transport.http.HTTPInTransport;
import org.opensaml.ws.transport.http.HttpServletRequestAdapter;

import at.gv.egiz.moodle.eidconnector.EIDConnectorException;
import at.gv.egiz.moodle.eidconnector.ErrorCode;
import eu.stork.mw.messages.saml.STORKResponse;

/**
 * @author AT-TUG (Thomas Knall)
 */
public class PEPSAuthenticationProviderImpl extends PEPSAuthenticationProvider {
   
   private final Logger log = Logger.getLogger(PEPSAuthenticationProviderImpl.class);

   public PEPSAuthenticationProviderImpl() {
   }

   @Override
   protected STORKResponse getSTORKResponse(HttpServletRequest request) throws EIDConnectorException {
      // decode message (decoding base64, checking if destination parameter matches HttpservletRequest
      BasicSAMLMessageContext samlMessageContext = new BasicSAMLMessageContext();
      HTTPInTransport httpInTransport = new HttpServletRequestAdapter(request);
      samlMessageContext.setInboundMessageTransport(httpInTransport);
      HTTPPostDecoder postDecoder = new HTTPPostDecoder();
      try {
         postDecoder.decode(samlMessageContext);
      } catch (Exception e) {
         log.error("Error decoding SAMLResponse message", e);
         throw new EIDConnectorException(ErrorCode.AUTH_PROVIDER_ERROR, "Error decoding SAMLResponse message", e);
      }
      
      // check if we have a SAMLResponse
      if (!(samlMessageContext.getInboundSAMLMessage() instanceof STORKResponse)) {
         throw new EIDConnectorException(ErrorCode.AUTH_PROVIDER_ERROR, "Message received is not a SAMLResponse message");
      }
      STORKResponse samlResponse = (STORKResponse) samlMessageContext.getInboundSAMLMessage();
      return samlResponse;
   }

}
