/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.auth.impl;

import java.util.Date;
import java.util.Random;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.time.DateFormatUtils;
import org.apache.log4j.Logger;

import at.gv.egiz.moodle.eidconnector.EIDConnectorException;
import at.gv.egiz.moodle.eidconnector.auth.AuthenticationProvider;
import at.gv.egiz.moodle.eidconnector.auth.data.SubjectAttributes;
import at.iaik.commons.util.CryptUtil;

/**
 * @author AT-TUG (Thomas Knall)
 */
public class TestAuthenticationProviderImpl implements AuthenticationProvider {
   
   private final Logger log = Logger.getLogger(TestAuthenticationProviderImpl.class);
   private Random rnd;

   public TestAuthenticationProviderImpl() {
      this.rnd = new Random();
      log.warn(this.getClass().getName() + " has been configured. This class should only be used for testing purposes.");
   }

   public SubjectAttributes authenticate(HttpServletRequest request) throws EIDConnectorException {
      
      // credentials that have to be provided to Moodle eIdConnector
      SubjectAttributes sa = new SubjectAttributes();
      
      // At this point normally a communication channel is established to the authentication
      // framework using the token from the given request in order to retrieve credentials.
      // String token = request.getParameter("token");
      // Since this is a test class we set some dummy credentials.
      
      // set the date of birth (if available)
      // in case of TestAuthenticationProviderImpl this is just a random date for testing purposes
      sa.setDateOfBirth(DateFormatUtils.format(new Date(this.rnd.nextLong() % new Date().getTime()), "yyyy-MM-dd"));
      
      // set the eIdentifier (mandatory)
      // in case of TestAuthenticationProviderImpl this is just a random value
      sa.setEIdentifier("TEST/" + CryptUtil.calcRandomText(CryptUtil.ALPHABETH_EASY_TO_READ_WITH_NUMBERS, 20));
      
      // set given name if available
      sa.setGivenName("John");
      
      // set family name if available
      sa.setSurName("Doe");
      
      log.debug("TestAuthenticationProvider returns: " + sa);
      
      return sa;
   }

   public boolean isResponsible(HttpServletRequest request) throws EIDConnectorException {
      
      // Normally the request is evaluated upon parameters suitable for this authentication
      // provider class
      // for example:
      // return request.getParameter("token") != null;
      
      // since this is a test class we always return true.
      
      return true;
   }

}
