/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.auth.impl;

import iaik.utils.Base64InputStream;

import java.io.ByteArrayInputStream;
import java.io.UnsupportedEncodingException;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;
import org.opensaml.xml.Configuration;
import org.opensaml.xml.io.Unmarshaller;
import org.opensaml.xml.io.UnmarshallerFactory;
import org.opensaml.xml.io.UnmarshallingException;
import org.opensaml.xml.parse.BasicParserPool;
import org.opensaml.xml.parse.XMLParserException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import at.gv.egiz.moodle.eidconnector.EIDConnectorException;
import at.gv.egiz.moodle.eidconnector.ErrorCode;
import eu.stork.mw.messages.saml.STORKResponse;

/**
 * @author AT-TUG (Thomas Knall)
 */
public class TestPEPSAuthenticationProviderImpl extends PEPSAuthenticationProvider {
   
   private Logger log = Logger.getLogger(TestPEPSAuthenticationProviderImpl.class);

   public TestPEPSAuthenticationProviderImpl() {
   }

   @Override
   protected STORKResponse getSTORKResponse(HttpServletRequest request) throws EIDConnectorException {

      try {
         log.warn("Test PEPS Authentication Provider invoked. This version does not check the Destination attribute.");
         
         // Get response
         String base64EncodedPEPSResponse = request.getParameter(SAML_RESPONSE_PARAM_NAME);
   
         // Base64 decode
         Base64InputStream base64InputStream = new Base64InputStream(
               new ByteArrayInputStream(
                     base64EncodedPEPSResponse.getBytes("UTF-8")
               ),
               true
         );
   
         // Get parser pool manager
         BasicParserPool ppMgr = new BasicParserPool();
         ppMgr.setNamespaceAware(true);
   
         Document responseDoc = ppMgr.parse(base64InputStream);
         Element responseRoot = responseDoc.getDocumentElement();
   
         // Get apropriate unmarshaller
         UnmarshallerFactory unmarshallerFactory = Configuration.getUnmarshallerFactory();
         Unmarshaller unmarshaller = unmarshallerFactory.getUnmarshaller(responseRoot);
   
         // Unmarshall using the document root element, an EntitiesDescriptor in
         // this case
         STORKResponse samlResponse = (STORKResponse) unmarshaller.unmarshall(responseRoot);
         return samlResponse;

      } catch (UnsupportedEncodingException e) {
         throw new EIDConnectorException(ErrorCode.AUTH_PROVIDER_ERROR, e);
      } catch (UnmarshallingException e) {
         throw new EIDConnectorException(ErrorCode.AUTH_PROVIDER_ERROR, e);
      } catch (XMLParserException e) {
         throw new EIDConnectorException(ErrorCode.AUTH_PROVIDER_ERROR, e);
      }
   }

}
