/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.core;

import org.apache.log4j.Logger;

import at.gv.egiz.moodle.eidconnector.auth.data.SubjectAttributesStore;

/**
 * @author AT-TUG (Thomas Knall)
 */
public class CleanUpThread implements Runnable {
   
   private static final long CLEANUP_INTERVAL_IN_SECONDS = 60;
   
   private long cleanUpInterval;
   
   private static final Logger log = Logger.getLogger(CleanUpThread.class);
   
   public CleanUpThread() {
      this.cleanUpInterval = CLEANUP_INTERVAL_IN_SECONDS;
   }

   protected long getCleanUpInterval() {
      return this.cleanUpInterval;
   }

   protected void setCleanUpInterval(long cleanUpInterval) {
      this.cleanUpInterval = cleanUpInterval;
   }

   public void run() {
      while (true) {
         try {
            Thread.sleep(this.cleanUpInterval * 1000);
         } catch (InterruptedException e) {
         }
         log.trace("Cleanup thread invoked.");
         SubjectAttributesStore.getInstance().cleanUp();
      }
   }
   
   public static void start() {
      CleanUpThread cleanUpThread = new CleanUpThread();
      log.debug("Cleanup thread initialized (will start every " + cleanUpThread.getCleanUpInterval() + " seconds).");
      Thread cleanupThread = new Thread(cleanUpThread);
      cleanupThread.setDaemon(true);
      cleanupThread.setName(CleanUpThread.class.getName());
      cleanupThread.setPriority(Thread.MIN_PRIORITY);
      cleanupThread.start();
   }

}
