/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.core.config;

import iaik.security.ecc.provider.ECCProvider;
import iaik.security.provider.IAIK;

import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.opensaml.xml.ConfigurationException;

import at.iaik.commons.jconfig.JConfigDefaultConfiguration;
import at.iaik.commons.jconfig.JConfigDefaultConfigurationException;
import at.iaik.commons.jconfig.JConfigDefaultValidator;
import at.iaik.commons.metadata.CommonsIAIK;
import at.iaik.commons.util.EncodingUtil;
import at.iaik.commons.util.HibernateUtil;
import at.iaik.commons.util.MiscUtil;
import eu.stork.vidp.messages.common.STORKBootstrap;

/**
 * @author AT-TUG (Thomas Knall)
 */
public final class Configuration extends JConfigMapper {

   public static final String WEB_XML_INIT_PARAMETER   = "cfgURI";
   public static final String MAIN_CFG_SYSTEM_PROPERTY = "moodleeidconnector.configuration";
   public static final String MAIN_CFG_FOLDER_SYSTEM_PROPERTY = "moodleeidconnector.configdir";
	public static final String MAIN_CONFIG_FILE_NAME = "application_config.xml";
	
	public static final String MAIN_CFG_RESOURCE_URI    = MAIN_CONFIG_FILE_NAME;
	public static final String DEFAULT_CFG_RESOURCE_URI = "at/gv/egiz/moodle/eidconnector/core/config/application_default_config.xml";
	public static final String APPLICATION_NAME = "Moodle-eID-connector";

	public static final String HBM_NAME_EID_CONNECTOR = "eid-connector";
	public static final String HBM_NAME_MOODLE = "moodle";

	private static boolean inited = false;
	private static String mainConfigURI = null;
	
	public static final int DELIVERY_APP_ID_SIZE = 8;
	public static final int AUTH_TOKEN_SIZE = 16;
	
	private static final Logger LOG = Logger.getLogger(Configuration.class);

	private Configuration() {
	}
	
	public static void init() throws JConfigDefaultConfigurationException, ConfigurationException {
		init(mainConfigURI);
	}
	
	public static boolean isConfigurationInited() {
	   return inited;
	}
	
	public static synchronized void init(String configURI) throws JConfigDefaultConfigurationException, ConfigurationException {
		if (!inited) {
			
		   LOG.debug("Adding IAIK JCE as provider.");
			IAIK.addAsProvider();
			LOG.debug("Adding IAIK ECC as provider.");
			ECCProvider.addAsProvider();
			
			CommonsIAIK.init();
			EncodingUtil.logEncoding(LOG);
			
			// JCONFIG
			if (MiscUtil.isEmpty(configURI)) {
				configURI = MAIN_CFG_RESOURCE_URI;
			}
			mainConfigURI = configURI;
			JConfigDefaultConfiguration cfg = JConfigDefaultConfiguration.getInstance(
						MAIN_CFG_SYSTEM_PROPERTY,
						configURI,
						DEFAULT_CFG_RESOURCE_URI
			);
			LOG.info("Main configuration   :  " + cfg.getMainConfigURI());
			LOG.info("Default configuration:  " + cfg.getDefaultConfigURI());

			// validate configuration
			JConfigDefaultValidator cValidator = new JConfigValidatorImpl(cfg);
			cValidator.validate();
			if (cValidator.getMaxSeverity().isGreaterOrEqual(Level.ERROR)) {
				throw new JConfigDefaultConfigurationException("Configuration error(s) detected.");
			}
			
			setConfig(cfg);
			
			// SAML
         STORKBootstrap.bootstrap();
			
         // hibernate
         HibernateUtil.initHibernate(
               Configuration.HBM_NAME_EID_CONNECTOR,
               createHibernateEIDConnectorConfiguration()
         );

         HibernateUtil.initHibernate(
               Configuration.HBM_NAME_MOODLE,
               createHibernateMoodleConfiguration()
         );

         inited = true;
         
         if (isMaintenanceMode()) {
            LOG.warn("******  System is in MAINTENANCE MODE.  ******");
         }
         
         if (isEIdTransformationSupported()) {
            LOG.warn("EID transformation support enabled. Should be disabled as soon as transformation process is finalized.");
         }
         
		}
	}

}
