/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.core.config;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;
import java.util.ResourceBundle;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.text.StrSubstitutor;
import org.jconfig.Category;

import at.gv.egiz.moodle.eidconnector.data.EIDMoodleUserMapping;
import at.gv.egiz.moodle.eidconnector.data.IdMapping;
import at.gv.egiz.moodle.eidconnector.data.MoodleUser;
import at.gv.egiz.moodle.eidconnector.data.StatisticLog;
import at.gv.egiz.moodle.eidconnector.webapp.struts.Constants;
import at.gv.egiz.moodle.eidconnector.webapp.util.WebAppUtil;
import at.iaik.commons.jconfig.JConfigDefaultConfiguration;
import at.iaik.commons.util.JConfigUtil;
import at.iaik.commons.util.MiscUtil;

/**
 * @author AT-TUG (Thomas Knall)
 */
public class JConfigMapper {

   public static final String CONFIG_STORK_AUTHENTICATOR_ID = "STORK";

	private static JConfigDefaultConfiguration cfg = null;
	
	private static Map<String, String> eIDHTTPHeaderMappings;
	
	public static void setConfig(org.jconfig.Configuration jconfig) {
		JConfigMapper.cfg = new JConfigDefaultConfiguration(jconfig, null);
	}
	
	public static void setConfig(JConfigDefaultConfiguration config) {
		JConfigMapper.cfg = config;
	}
	
	protected JConfigMapper() {
	}
	
	// MAPPINGS
	public static Map<String, String> getEIDHTTPHeaderMappings() {
	   if (eIDHTTPHeaderMappings == null) {
         Map<String, String> result = new HashMap<String, String>();
         Category cat = cfg.getCategory("eid-http-header-mappings");
         if (cat != null) {
            Category[] nc = JConfigUtil.getNestedCategories(cat);
            for (Category lCat : nc) {
               String eIDAttributeName = cfg.getProperty("eid-attribute", null, "eid-http-header-mappings/" + lCat.getCategoryName());
               String httpHeaderName = cfg.getProperty("http-header", null, "eid-http-header-mappings/" + lCat.getCategoryName());
               if (MiscUtil.areAllNotEmpty(eIDAttributeName, httpHeaderName)) {
                  result.put(eIDAttributeName, httpHeaderName);
               }
            }
         }
         eIDHTTPHeaderMappings = Collections.unmodifiableMap(result);
	   }
      return eIDHTTPHeaderMappings;
	}
	
	
	public static Properties getHibernateConfiguration(String category) {
	   return MiscUtil.substituteSysProps(cfg.getProperties("hibernate/" + category));
	}
	
	public static org.hibernate.cfg.AnnotationConfiguration createHibernateEIDConnectorConfiguration() {
	   org.hibernate.cfg.AnnotationConfiguration hbConfig = new org.hibernate.cfg.AnnotationConfiguration();
      hbConfig.setProperties(getHibernateConfiguration(Configuration.HBM_NAME_EID_CONNECTOR));
	   hbConfig.addAnnotatedClass(EIDMoodleUserMapping.class);
      if (Configuration.isEIdTransformationSupported()) {
         hbConfig.addAnnotatedClass(IdMapping.class);
      }
      if (Configuration.isDatabaseLoggingSupported()) {
         hbConfig.addAnnotatedClass(StatisticLog.class);
      }
	   return hbConfig;
	}
	
   public static org.hibernate.cfg.AnnotationConfiguration createHibernateMoodleConfiguration() {
      org.hibernate.cfg.AnnotationConfiguration hbConfig = new org.hibernate.cfg.AnnotationConfiguration();
      hbConfig.setProperties(getHibernateConfiguration(Configuration.HBM_NAME_MOODLE));
      hbConfig.addAnnotatedClass(MoodleUser.class);
      return hbConfig;
   }

	// general
	
   public static String getGeneralProperty(String property) {
      return cfg.getProperty(property, null, "general");
   }
   
   public static int getInternalIntProperty(String property) {
      return cfg.getIntProperty(property, 0, "internal");
   }
   
   public static String getInternalProperty(String property) {
      return cfg.getProperty(property, null, "internal");
   }
   
   public static boolean isEIdTransformationSupported() {
      return cfg.getBooleanProperty("eid.transformation.enabled", false, "internal");
   }
   
   public static boolean isDatabaseLoggingSupported() {
      return cfg.getBooleanProperty("logger.database.enabled", false, "internal");
   }
   
   public static boolean getInternalBooleanProperty(String property) {
      return cfg.getBooleanProperty(property, true, "internal");
   }
   
   public static boolean isMaintenanceMode() {
      return cfg.getBooleanProperty("maintenancemode", false, "internal");
   }
   
	public static boolean isForceAgeCalculationEnabled() {
	   return cfg.getBooleanProperty("force.calculate.age", false, "internal");
	}
	
	// error
	
   public static ResourceBundle getResourceBundle() {
      String resourceBundleName = cfg.getProperty("resourcebundle", null, "general");
      ResourceBundle bundle = null;
      if (MiscUtil.isNotEmpty(resourceBundleName)) {
         bundle = ResourceBundle.getBundle(resourceBundleName);
      }
      return bundle;
   }

   public static String getErrorProperty(String property, HttpServletRequest request) {
      return WebAppUtil.replaceI18N(cfg.getProperty(property, null, "error"), request); 
   }
   
   public static ResourceBundle getGeneralResourceBundleProperty(String property, Locale locale) {
      return cfg.getResourceBundleProperty(property, null, locale, "general");
   }
   
   public static String getErrorProperty(String property) {
      return getErrorProperty(property, null); 
   }

   // general
	public static boolean getGeneralBooleanProperty(String property) {
		return cfg.getBooleanProperty(property, true, "general");	
	}
	
	public static String getAuthCountryProperty(String countryCode, String property) {
	   return cfg.getProperty(property, null, "auth/" + countryCode);
	}
	
	public static boolean isAuthCountryEnabled(String countryCode) {
	   return cfg.getBooleanProperty("enabled", true, "auth/" + countryCode);
	}

	public static Category[] getNestedCategories(String category) {
      Category cat = cfg.getCategory(category);
      return cat == null ? null : JConfigUtil.getNestedCategories(cat);
	}
	
	public static String getMOAIDProperty(String instance, String property) {
		return MiscUtil.substituteSysProps(cfg.getProperty(property, null, "moaid/" + instance));
	}
	
   public static Integer getMOAIDQAALevel(String instance) {
      String value = cfg.getProperty("default.qaa.level", null, "moaid/" + instance);
      Integer result = null;
      if (value != null) {
         try {
            result = Integer.parseInt(value);
         } catch (NumberFormatException e) {
         }
      }
      return result;
   }

   public static String getMOAIDNationalityCode(String instance) {
      return StringUtils.trimToNull(cfg.getProperty("default.nationality.code", null, "moaid/" + instance));
   }

	public static String getMOAIDProperty(String instance, String property, HttpServletRequest request) {
      String value = cfg.getProperty(property, null, "moaid/" + instance);
      if (value != null) {
         value = MiscUtil.substituteSysProps(value);
         if (request != null) {
            Map<String, String> map = new HashMap<String, String>();
            map.put("scheme", request.getScheme());
            map.put("host", request.getServerName());
            map.put("port", String.valueOf(request.getServerPort()));
            map.put("context", MiscUtil.removePrecedingSlash(request.getContextPath()));
            map.put("serverurl", at.iaik.commons.util.WebAppUtil.getServerURL(request));
            map.put("baseurl", at.iaik.commons.util.WebAppUtil.getBaseURL(request));
            value = (new StrSubstitutor(map)).replace(value);
         }
      }
      return value;
   }
	
	public static String[] getMOAIDInstanceNames() {
      Category cat = cfg.getCategory("moaid");
      Category[] cats = (cat == null ? null : JConfigUtil.getNestedCategories(cat));
      ArrayList<String> names = new ArrayList<String>();
      for (Category c : cats) {
         if (!Constants.DEFAULT_STORK_MOA_ID_CATEGORY_NAME.equals(c.getCategoryName())) {
            names.add(c.getCategoryName());
         }
      }
      return names.toArray(new String[names.size()]);
	}
	
   // moodle
   public static String getMoodleProperty(String property) {
      return StringUtils.trimToNull(cfg.getProperty(property, null, "moodle"));
   }
   
   public static String[] getMoodleAccountSalts() {
      return getMoodleArrayProperty("moodle.password.salt");
   }
   
   public static String getMoodleOldCharset() {
      return getMoodleProperty("moodle.password.oldcharset");
   }
   
   public static boolean isMoodleExistingAccountsEnabled() {
      return cfg.getBooleanProperty("moodle.existing.accounts", true, "moodle");
   }
   
   public static boolean isMoodleNewAccountsEnabled() {
      return cfg.getBooleanProperty("moodle.new.accounts", true, "moodle");
   }
   
   public static String[] getMoodleArrayProperty(String property) {
      String[] array = cfg.getArrayProperty(property, new String[] { }, "moodle");
      return array;
   }
   
   // STORKResponseValidation
   public static String[] getSTORKResponseValidationTrustedIssuers() {
      String[] trustedIssuers = cfg.getArrayProperty("trusted.issuers", new String[] { }, "STORKResponseValidation");
      return trustedIssuers;
   }
   
   public static boolean isSTORKResponseValidationTrustedIssuer(String issuer) {
      if (issuer == null) {
         return false;
      }
      return MiscUtil.in(issuer, getSTORKResponseValidationTrustedIssuers());
   }
   
   public static String getSTORKResponseValidationExpectedAudience() {
      return StringUtils.trimToNull(cfg.getProperty("expected.audience", null, "STORKResponseValidation"));
   }
   
   public static String getSTORKResponseValidationSignatureVerificationConfigPath() {
      String path = StringUtils.trimToNull(cfg.getProperty("signature-verification.config-path", null, "STORKResponseValidation"));
      if (path != null) {
         path = MiscUtil.substituteSysProps(path);
      }
      return path;
   }
   
   public static String getSTORKResponseValidationSignatureVerificationProfile() {
      return StringUtils.trimToNull(cfg.getProperty("signature-verification.profile", null, "STORKResponseValidation"));
   }
   
}
