/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.data;

import java.io.Serializable;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * @author AT-TUG (Thomas Knall)
 */
@Entity
@Table(name = "eid_moodleuser_mapping")
public class EIDMoodleUserMapping implements Serializable {

   private static final long serialVersionUID = 1L;
   
   // fields
   
   @Id @GeneratedValue(strategy = GenerationType.AUTO)
   private Integer id;

   @Basic
   @Column(name = "eid", nullable = false, unique = true)
   private String eIdentifier;
   
   @Basic
   @Column(name = "equalifier", nullable = true, unique = false)
   /**
    * This field was created in order to allow further information on the eIdentifier.
    */
   private String eQualifier;
   
   @Basic
   @Column(name = "moodle_user_id", nullable = false, unique = false)
   private Integer moodleUserId;
   
   // constructor
   public EIDMoodleUserMapping() {
      this.id = null;
      this.eIdentifier = null;
      this.moodleUserId = null;
      this.eQualifier = null;
   }

   // getter/setter

   public Integer getId() {
      return this.id;
   }

   public void setId(Integer id) {
      this.id = id;
   }

   public String getEIdentifier() {
      return this.eIdentifier;
   }

   public void setEIdentifier(String identifier) {
      this.eIdentifier = identifier;
   }

   public Integer getMoodleUserId() {
      return this.moodleUserId;
   }

   public void setMoodleUserId(Integer moodleUserId) {
      this.moodleUserId = moodleUserId;
   }

   public String getEQualifier() {
      return this.eQualifier;
   }

   public void setEQualifier(String qualifier) {
      this.eQualifier = qualifier;
   }

   @Override
   public int hashCode() {
      final int prime = 31;
      int result = 1;
      result = prime * result + ((this.eIdentifier == null) ? 0 : this.eIdentifier.hashCode());
      result = prime * result + ((this.eQualifier == null) ? 0 : this.eQualifier.hashCode());
      result = prime * result + ((this.id == null) ? 0 : this.id.hashCode());
      result = prime * result + ((this.moodleUserId == null) ? 0 : this.moodleUserId.hashCode());
      return result;
   }

   @Override
   public boolean equals(Object obj) {
      if (this == obj) {
         return true;
      }
      if (obj == null) {
         return false;
      }
      if (getClass() != obj.getClass()) {
         return false;
      }
      EIDMoodleUserMapping other = (EIDMoodleUserMapping) obj;
      if (this.eIdentifier == null) {
         if (other.eIdentifier != null) {
            return false;
         }
      } else if (!this.eIdentifier.equals(other.eIdentifier)) {
         return false;
      }
      if (this.eQualifier == null) {
         if (other.eQualifier != null) {
            return false;
         }
      } else if (!this.eQualifier.equals(other.eQualifier)) {
         return false;
      }
      if (this.id == null) {
         if (other.id != null) {
            return false;
         }
      } else if (!this.id.equals(other.id)) {
         return false;
      }
      if (this.moodleUserId == null) {
         if (other.moodleUserId != null) {
            return false;
         }
      } else if (!this.moodleUserId.equals(other.moodleUserId)) {
         return false;
      }
      return true;
   }

   @Override
   public String toString() {
      return new ToStringBuilder(this)
         .append("id", this.id)
         .append("eIdentifier", this.eIdentifier)
         .append("eQualifier", this.eQualifier)
         .append("moodleUserId", this.moodleUserId)
      .toString();
   }

}
