/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.data;

import java.io.Serializable;
import java.util.Date;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * @author AT-TUG (Thomas Knall)
 */
/*
@Cache(usage = CacheConcurrencyStrategy.READ_ONLY)
@Immutable
 */
@Entity
@Table(name = "persondata_eid_mapping")
public class IdMapping implements Serializable {

   private static final long serialVersionUID = 1L;
   
   // fields
   
   @Id @GeneratedValue(strategy = GenerationType.AUTO)
   private int id;

   @Basic
   @Column(name = "givennames", unique = false, nullable = false)
   private String givenNames;
   
   @Basic
   @Column(name = "familyname", unique = false, nullable = false)
   private String familyName;
   
   @Temporal(TemporalType.DATE)
   @Column(name = "date_of_birth", nullable = false)
   private Date dateOfBirth;
   
   @Basic
   @Column(name = "nameidentifier", unique = false, nullable = false)
   private String nameIdentifier;
   
   @Basic
   @Column(name = "namequalifier", unique = false, nullable = true)
   private String nameQualifier;
   
   
   // constructor
   public IdMapping() {
   }
   
   public IdMapping(String givenNames, String familyName, Date dateOfBirth, String nameIdentifier, String nameQualifier) {
      this.givenNames = givenNames;
      this.familyName = familyName;
      this.dateOfBirth = dateOfBirth;
      this.nameIdentifier = nameIdentifier;
      this.nameQualifier = nameQualifier;
   }

   public IdMapping(String givenNames, String familyName, Date dateOfBirth) {
      this(givenNames, familyName, dateOfBirth, null, null);
   }

   // getter/setter

   public int getId() {
      return this.id;
   }

   public void setId(int id) {
      this.id = id;
   }

   public String getNameIdentifier() {
      return this.nameIdentifier;
   }

   public void setNameIdentifier(String nameIdentifier) {
      this.nameIdentifier = nameIdentifier;
   }

   public String getNameQualifier() {
      return this.nameQualifier;
   }

   public void setNameQualifier(String nameQualifier) {
      this.nameQualifier = nameQualifier;
   }

   public String getGivenNames() {
      return this.givenNames;
   }

   public void setGivenNames(String givenNames) {
      this.givenNames = givenNames;
   }

   public String getFamilyName() {
      return this.familyName;
   }

   public void setFamilyName(String familyName) {
      this.familyName = familyName;
   }

   public Date getDateOfBirth() {
      return this.dateOfBirth;
   }

   public void setDateOfBirth(Date dateOfBirth) {
      this.dateOfBirth = dateOfBirth;
   }

   @Override
   public int hashCode() {
      final int prime = 31;
      int result = 1;
      result = prime * result + ((this.dateOfBirth == null) ? 0 : this.dateOfBirth.hashCode());
      result = prime * result + ((this.familyName == null) ? 0 : this.familyName.hashCode());
      result = prime * result + ((this.givenNames == null) ? 0 : this.givenNames.hashCode());
      result = prime * result + this.id;
      result = prime * result
               + ((this.nameIdentifier == null) ? 0 : this.nameIdentifier.hashCode());
      result = prime * result + ((this.nameQualifier == null) ? 0 : this.nameQualifier.hashCode());
      return result;
   }

   @Override
   public boolean equals(Object obj) {
      if (this == obj)
         return true;
      if (obj == null)
         return false;
      if (getClass() != obj.getClass())
         return false;
      IdMapping other = (IdMapping) obj;
      if (this.dateOfBirth == null) {
         if (other.dateOfBirth != null)
            return false;
      } else if (!this.dateOfBirth.equals(other.dateOfBirth))
         return false;
      if (this.familyName == null) {
         if (other.familyName != null)
            return false;
      } else if (!this.familyName.equals(other.familyName))
         return false;
      if (this.givenNames == null) {
         if (other.givenNames != null)
            return false;
      } else if (!this.givenNames.equals(other.givenNames))
         return false;
      if (this.id != other.id)
         return false;
      if (this.nameIdentifier == null) {
         if (other.nameIdentifier != null)
            return false;
      } else if (!this.nameIdentifier.equals(other.nameIdentifier))
         return false;
      if (this.nameQualifier == null) {
         if (other.nameQualifier != null)
            return false;
      } else if (!this.nameQualifier.equals(other.nameQualifier))
         return false;
      return true;
   }

   @Override
   public String toString() {
      return new ToStringBuilder(this)
         .append("id", this.id)
         .append("givenNames", this.givenNames)
         .append("familyName", this.familyName)
         .append("dateOfBirth", this.dateOfBirth)
         .append("nameIdentifier", this.nameIdentifier)
         .append("nameQualifier", this.nameQualifier)
      .toString();
   }

}
