/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.data;

import java.io.Serializable;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.Table;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * @author AT-TUG (Thomas Knall)
 */
/*
@Cache(usage = CacheConcurrencyStrategy.READ_ONLY)
@Immutable
 */
@Entity
@Table(name = "mdl_user")
public class MoodleUser implements Serializable {

   private static final long serialVersionUID = 1L;
   
   // fields
   
   @Id @GeneratedValue(strategy = GenerationType.AUTO)
   private int id;

   @Basic
   @Column(name = "auth", unique = false, nullable = false, length = 20)
   private String auth;
   
   @Basic
   @Column(name = "deleted", nullable = false)
   private Boolean deleted;
   
   @Basic
   @Column(name = "username", nullable = false, length = 100)
   private String username;
   
   @Basic
   @Column(name = "password", nullable = false, length = 32)
   private String hashOfPassword;
   

   // constructor
   public MoodleUser() {
      this.auth = null;
      this.username = null;
      this.hashOfPassword = null;
      this.deleted = null;
   }
   
   @Override
   public int hashCode() {
      final int prime = 31;
      int result = 1;
      result = prime * result + ((this.auth == null) ? 0 : this.auth.hashCode());
      result = prime * result + ((this.deleted == null) ? 0 : this.deleted.hashCode());
      result = prime * result
            + ((this.hashOfPassword == null) ? 0 : this.hashOfPassword.hashCode());
      result = prime * result + this.id;
      result = prime * result + ((this.username == null) ? 0 : this.username.hashCode());
      return result;
   }

   @Override
   public boolean equals(Object obj) {
      if (this == obj) {
         return true;
      }
      if (obj == null) {
         return false;
      }
      if (getClass() != obj.getClass()) {
         return false;
      }
      MoodleUser other = (MoodleUser) obj;
      if (this.auth == null) {
         if (other.auth != null) {
            return false;
         }
      } else if (!this.auth.equals(other.auth)) {
         return false;
      }
      if (this.deleted == null) {
         if (other.deleted != null) {
            return false;
         }
      } else if (!this.deleted.equals(other.deleted)) {
         return false;
      }
      if (this.hashOfPassword == null) {
         if (other.hashOfPassword != null) {
            return false;
         }
      } else if (!this.hashOfPassword.equals(other.hashOfPassword)) {
         return false;
      }
      if (this.id != other.id) {
         return false;
      }
      if (this.username == null) {
         if (other.username != null) {
            return false;
         }
      } else if (!this.username.equals(other.username)) {
         return false;
      }
      return true;
   }
   // getter/setter

   public int getId() {
      return this.id;
   }

   public void setId(int id) {
      this.id = id;
   }

   public String getAuth() {
      return this.auth;
   }

   public void setAuth(String auth) {
      this.auth = auth;
   }

   public String getUsername() {
      return this.username;
   }

   public void setUsername(String username) {
      this.username = username;
   }

   public String getHashOfPassword() {
      return this.hashOfPassword;
   }

   public void setHashOfPassword(String hashOfPassword) {
      this.hashOfPassword = hashOfPassword;
   }

   public Boolean getDeleted() {
      return this.deleted;
   }

   public void setDeleted(Boolean deleted) {
      this.deleted = deleted;
   }

   @Override
   public String toString() {
      return new ToStringBuilder(this)
         .append("id", this.id)
         .append("auth", this.auth)
         .append("deleted", this.deleted)
         .append("username", this.username)
//         .append("hashOfPassword", this.hashOfPassword == null ? "<not set>" : "<set>")
         .append("hashOfPassword", this.hashOfPassword)
      .toString();
   }

}
