/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.data.ap;

import java.util.List;

import org.apache.commons.lang.time.StopWatch;
import org.apache.log4j.Logger;
import org.hibernate.Criteria;
import org.hibernate.HibernateException;
import org.hibernate.Session;
import org.hibernate.Transaction;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.Restrictions;

import at.gv.egiz.moodle.eidconnector.core.config.Configuration;
import at.gv.egiz.moodle.eidconnector.data.EIDMoodleUserMapping;
import at.iaik.commons.util.HibernateUtil;
import at.iaik.commons.util.MiscUtil;
import at.iaik.commons.util.ToStringUtil;

/**
 * @author AT-TUG (Thomas Knall)
 */
public final class EIDMoodleUserMappingAP {
   
   private static final Logger LOG = Logger.getLogger(EIDMoodleUserMappingAP.class);
   
   private EIDMoodleUserMappingAP() {
   }

   @SuppressWarnings("unchecked")
   public static List<EIDMoodleUserMapping> findMappingsByCriterion(Criterion... criterions) {
      Transaction tx = null;
      List<EIDMoodleUserMapping> result = null;
      StopWatch sw = new StopWatch();
      sw.start();
      try {
         Session session = HibernateUtil.getCurrentSession(Configuration.HBM_NAME_EID_CONNECTOR);
         tx = session.beginTransaction();

         Criteria criteria = session.createCriteria(EIDMoodleUserMapping.class);

         if (MiscUtil.isNotEmpty(criterions)) {
            LOG.debug("Looking for user mapping(s) (criterion(s) = " + ToStringUtil.toString(criterions) + ").");
            for (Criterion criterion : criterions) {
               criteria.add(criterion);
            }
         }
         LOG.debug("Effective criteria: " + criteria.toString());
         result = criteria.list();
         tx.commit();
         sw.stop();
         LOG.debug("Found " + result.size() + " user mapping(s). Query time: " + sw.getTime() + "ms.");
      } catch (HibernateException hex) {
         LOG.error(hex);
         if (tx != null) {
            LOG.debug("Initiating rollback.");
            try {
               tx.rollback();
            } catch (HibernateException rollbackFailed) {
               LOG.error("Rollback failed (reason: " + rollbackFailed.getMessage() + ")");
            }
         }
         sw.stop();
         LOG.debug("Transaction aborted after " + sw.getTime() + "ms.");
         throw hex;
      }
      return result;
   }

   protected static EIDMoodleUserMapping findMappingByCriterion(Criterion... criterions) {
      MiscUtil.assertNotEmpty(criterions, "Criterions");
      Transaction tx = null;
      EIDMoodleUserMapping result = null;
      StopWatch sw = new StopWatch();
      sw.start();
      try {
         Session session = HibernateUtil.getCurrentSession(Configuration.HBM_NAME_EID_CONNECTOR);
         tx = session.beginTransaction();

         Criteria criteria = session.createCriteria(EIDMoodleUserMapping.class);
         if (MiscUtil.isNotEmpty(criterions)) {
            LOG.debug("Looking for user mapping (criterion(s) = " + ToStringUtil.toString(criterions) + ").");
            for (Criterion criterion : criterions) {
               criteria.add(criterion);
            }
         }
         LOG.debug("Effective criteria: " + criteria.toString());
         result = (EIDMoodleUserMapping) criteria.uniqueResult();
         tx.commit();
         sw.stop();
         LOG.debug((result != null ? "Found user mapping." : "Unable to find user mapping.") + " Query time: " + sw.getTime() + "ms.");
      } catch (HibernateException hex) {
         LOG.error(hex);
         if (tx != null) {
            LOG.debug("Initiating rollback.");
            try {
               tx.rollback();
            } catch (HibernateException rollbackFailed) {
               LOG.error("Rollback failed (reason: " + rollbackFailed.getMessage() + ")");
            }
         }
         sw.stop();
         LOG.debug("Transaction aborted after " + sw.getTime() + "ms.");
         throw hex;
      }
      return result;
   }

   
   public static EIDMoodleUserMapping findMappingById(long id) {
      MiscUtil.assertNotNull(id, "id");
      return findMappingByCriterion(Restrictions.eq("id", id));
   }
   
   public static EIDMoodleUserMapping findMappingByEIdentifier(String eIdentifier) {
      MiscUtil.assertNotNull(eIdentifier, "eIdentifier");
      return findMappingByCriterion(Restrictions.eq("eIdentifier", eIdentifier));
   }
   
}
