/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.logging;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import at.gv.egiz.moodle.eidconnector.EIDConnectorException;
import at.gv.egiz.moodle.eidconnector.core.config.Configuration;
import at.gv.egiz.moodle.eidconnector.logging.impl.SimpleStatisticLogger;
import at.iaik.commons.util.MiscUtil;

public class StatisticLoggerProvider {
   
   private static StatisticLogger statLogger;
   
   private static final Logger log = LoggerFactory.getLogger(StatisticLoggerProvider.class);
   
   public static synchronized StatisticLogger getInstance() throws EIDConnectorException {
      statLogger = null;
      if (statLogger == null) {
         if (MiscUtil.isNotEmpty(Configuration.getInternalProperty("logger.impl"))) {
            String cp = Configuration.getInternalProperty("logger.impl").trim();
            log.debug("Instantiating statistical logger implementation \"{}\".", cp);
            try {
               Class clazz = Class.forName(cp);
               Object loggerObj = clazz.newInstance(); 
               if (!(loggerObj instanceof StatisticLogger)) {
                  log.error("Defined statistical logger implementation \"{}\" is not an instance of \"{}\".", cp, StatisticLogger.class.getName());
               }
               statLogger = (StatisticLogger) loggerObj;
            } catch (InstantiationException e) {
               log.error("Unable to instantiate statistical logger implementation \"{}\".", cp, e);
            } catch (IllegalAccessException e) {
               log.error("Unable to instantiate statistical logger implementation \"{}\".", cp, e);
            } catch (ClassNotFoundException e) {
               log.error("Unable to instantiate statistical logger implementation \"{}\".", cp, e);
            }
         }
         if (statLogger == null) {
            log.warn("Using fallback statistical logger \"{}\".", SimpleStatisticLogger.class.getName());
            statLogger = new SimpleStatisticLogger();
         }
      }
      return statLogger;
   }

}
