/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.logging.impl;

import java.util.Date;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import at.gv.egiz.moodle.eidconnector.logging.StatisticLogger;

/**
 * A very simply version of a statistical logger.
 * @author AT-TUG (Thomas Knall)
 */
public class SimpleStatisticLogger implements StatisticLogger {

   private Logger log = LoggerFactory.getLogger(SimpleStatisticLogger.class);
   
   /**
    * Creates a log entry with log level DEBUG using the data provided.
    * Note that timestamp, assertionIssuerId and spID must not be {@code null}, while the remaining parameters
    * might be.<br/>
    * After parameter {@code age} an arbitrary number of various user defined parameters might be
    * passed. These additional fields are also logged if provided.<br/>
    * @param timestamp The current date.
    * @param assertionIssuerId The identifier of the underlying S-PEPS/V-IDP instance.
    * @param spID The identifier of the service provider being served.
    * @param sha1OfEID A base64 encoded String of the SHA1 hash of the citizen's eIdentifier.
    * @param citizenCountryCode The citizen's home country code (according to ISO 3166-1 alpha-2).
    * @param citizenQAALevel The underlying QAA level.
    * @param age The citizen's age.
    * @param others An arbitrary number of further fields to be logged.
    */
   public void log(Date timestamp, String assertionIssuerId, String spID, String sha1OfEID,
            String citizenCountryCode, Integer citizenQAALevel, Integer age, Object... other) {
      
      ToStringBuilder tos = new ToStringBuilder(this);
      tos
         .append("timestamp", timestamp)
         .append("assertionIssuerId", assertionIssuerId)
         .append("spID", spID)
         .append("sha1OfEID", sha1OfEID)
         .append("citizenCountryCode", citizenCountryCode)
         .append("citizenQAALevel", citizenQAALevel)
         .append("age", age);
      if (other != null) {
         for (int i = 0; i < other.length; i++) {
            tos.append("customField" + (i+1), other[i]);
         }
      }
      log.debug(tos.toString());
   }

}
