/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.webapp;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import org.apache.log4j.Logger;

import at.gv.egiz.moodle.eidconnector.core.config.Configuration;
import at.iaik.commons.util.MiscUtil;

/**
 * @author AT-TUG (Thomas Knall)
 */
public class ConfigFilter implements Filter {
   
   private static final String ERROR_PAGE_PARAM =  "errorPage";
   private String errorPage = null;
   private Logger log = Logger.getLogger(this.getClass());

   public void destroy() {
   }

   public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
      if (errorPage != null && !Configuration.isConfigurationInited()) {
         servletRequest.getRequestDispatcher(this.errorPage).forward(servletRequest, servletResponse);
      } else {
         filterChain.doFilter(servletRequest, servletResponse);
      }
   }

   public void init(FilterConfig filterConfig) throws ServletException {
      String errorPage = filterConfig.getInitParameter(ERROR_PAGE_PARAM);
      if (MiscUtil.isNotEmpty(errorPage)) {
         this.errorPage = errorPage;
         log.debug("Configuration filter initialized. Upon invalid configuration user will be forwarded to \"" + errorPage + "\".");
      } else {
         log.warn("Configuration filter disabled. Missing web.xml parameter \"" + ERROR_PAGE_PARAM + "\".");
      }
   }

}
