/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.webapp.struts;

import java.util.Date;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.WordUtils;
import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ExceptionHandler;
import org.apache.struts.config.ExceptionConfig;
import org.apache.struts.validator.Resources;

import at.gv.egiz.moodle.eidconnector.core.config.Configuration;
import at.iaik.commons.util.DateTimeUtil;
import at.iaik.commons.util.MiscUtil;
import at.iaik.commons.util.TextUtil;

/**
 * @author AT-TUG (Thomas Knall)
 */
public class CustomExceptionHandler extends ExceptionHandler {

	private static Logger log = Logger.getLogger(CustomExceptionHandler.class);
	private static final int WRAP_COLUMN = 60;
	
	private static String prepMailText(String text) {
		return
			WordUtils.wrap(
				TextUtil.normalizeText(text), WRAP_COLUMN, "\n            ", false
			);
	}

	public static String getMailToHREF(Exception ex, HttpServletRequest request) {
		return getMailToHREF(ex, null, request);
	}

	public static String getMailToHREF(String message, HttpServletRequest request) {
		return getMailToHREF(null, message, request);
	}

	private static String getMailToHREF(Exception ex, String message, HttpServletRequest request) {
		StringBuffer buffer = new StringBuffer();
		
		String to      = Configuration.getErrorProperty("mailto");
		if (MiscUtil.isEmpty(to)) {
		   return "";
		}
		String subject = TextUtil.prepareMessageText(Configuration.getErrorProperty("subject", request));
		String body    = TextUtil.prepareMessageText(Configuration.getErrorProperty("body", request));
		String cc      = Configuration.getErrorProperty("cc");
		String bcc     = Configuration.getErrorProperty("bcc");
		
		if (MiscUtil.isEmpty(subject) && (ex != null)) {
			subject = ex.getClass().getSimpleName();
		}
		
		if (MiscUtil.isEmpty(body)) {
			StringBuffer bb = new StringBuffer();
			
			bb.append("timestamp = ").append(DateTimeUtil.formatTimeStamp(new Date())).append("\n");
//			ByteArrayOutputStream bout = new ByteArrayOutputStream();
//			ex.printStackTrace(new PrintStream(bout));
//			bb.append(new String(bout.toByteArray()));
			
			if (ex != null) {
				bb.append("exception = ").append(ex.getClass().getName());
				bb.append(": ").append(prepMailText(ex.getMessage()));
			} else {
				bb.append("message = ").append(message);
			}
			body = bb.toString();
		}
		
		buffer.append("<a href=\"mailto:").append(at.iaik.commons.util.WebAppUtil.generateMailTo(to, subject, cc, bcc, body)).append("\">").append(to).append("</a>");
		
		return buffer.toString();
	}
	
	public ActionForward execute(Exception ex, ExceptionConfig ae, ActionMapping mapping,
			ActionForm formInstance, HttpServletRequest request, HttpServletResponse response)
			throws ServletException {

		log.error(ex.getMessage(), ex);

		String title    = Resources.getMessage(request, "errors.runtimeexception.title");
		String infotext = null;
		String subtitle = Resources.getMessage(request, "errors.runtimeexception.subtitle");
		String msg      = Resources.getMessage(request, "errors.runtimeexception.text");
		String content  =  (msg != null ? msg : "") + "<p>" + getMailToHREF(ex, request) + "</p>" +
		   "\n\n<!-- STACKTRACE\n" + ExceptionUtils.getFullStackTrace(ex) + "-->\n\n";

		at.iaik.commons.util.WebAppUtil.prepareStatusData(request, title, infotext, subtitle, content);
		return new ActionForward(ae.getPath());
	}

}
