/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.webapp.struts.action;

import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.util.Locale;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.log4j.Logger;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.actions.DispatchAction;
import org.apache.struts.util.MessageResources;

import at.gv.egiz.moodle.eidconnector.webapp.struts.Constants;
import at.iaik.commons.util.MiscUtil;

/**
 * @author AT-TUG (Thomas Knall)
 */
public class CommonAction extends DispatchAction {
	
	private final Logger log = Logger.getLogger(CommonAction.class);
	
   public ActionForward testException(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response) throws NoSuchAlgorithmException, IOException {
      log.debug("Exception handling test invoked.");
      String code = request.getParameter("code");
      if (MiscUtil.isEmpty(code)) {
         throw new RuntimeException("foo");
      }
      int codeValue = Integer.parseInt(code);
      response.sendError(codeValue);
      return null;
   }
   
   public ActionForward prepareMessagePage(ActionMapping mapping, HttpServletRequest request, String messageResourcePrefix, String forward, String... args) {
      Locale currentBrowserLocale = super.getLocale(request);
      MessageResources msgResources = getResources(request);
      String title = msgResources.getMessage(currentBrowserLocale, messageResourcePrefix + ".title");
      String subtitle = msgResources.getMessage(currentBrowserLocale, messageResourcePrefix + ".subtitle");
      String content;
      if (MiscUtil.isEmpty(args)) {
         content = msgResources.getMessage(currentBrowserLocale, messageResourcePrefix + ".content");
      } else {
         content = msgResources.getMessage(currentBrowserLocale, messageResourcePrefix + ".content", args);
      }
      at.iaik.commons.util.WebAppUtil.prepareStatusData(request, title, null, subtitle, content, forward);
      return mapping.findForward(Constants.FWD_STATUS);
   }
   
   @Override
   public ActionForward execute(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response) throws Exception {
      
      String dispatchParameter = mapping.getParameter();
      String dispatchParameterValue = super.getMethodName(mapping, form, request, response, dispatchParameter);
      if (MiscUtil.isEmpty(dispatchParameterValue)) {
         log.debug("Dispatch parameter \"" + dispatchParameter + "\" is missing. Forwarding to error page.");
         return prepareMessagePage(mapping, request, "errors.nodispatchparameter", null, dispatchParameter);
      }
      log.trace("dispatchParameterValue = \"" + dispatchParameterValue + "\"");
      try {
         super.getMethod(dispatchParameterValue);
         log.trace("Found appropriate method.");
      } catch (NoSuchMethodException noSuchMethodException) {
         log.error("There is no method \"" + dispatchParameterValue + "\".");
         return prepareMessagePage(mapping, request, "errors.invaliddispatchparameter", null, dispatchParameter, dispatchParameterValue);
      }
      at.iaik.commons.util.WebAppUtil.handOverWindowPosition(request);
      return super.execute(mapping, form, request, response);
   }
	
	@Override
	protected ActionForward cancelled(ActionMapping mapping, ActionForm form, HttpServletRequest request, HttpServletResponse response) {
		log.trace("Cancelling.");
		return mapping.findForward(Constants.FWD_LEAVE_CONNECTOR);
	}
   
}
