/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.moodle.eidconnector.webapp.util;

import iaik.utils.Util;

import java.io.UnsupportedEncodingException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.lang.text.StrSubstitutor;
import org.apache.log4j.Logger;

import at.gv.egiz.moodle.eidconnector.core.config.Configuration;
import at.gv.egiz.moodle.eidconnector.webapp.struts.Constants;
import at.iaik.commons.util.MiscUtil;
import at.iaik.commons.webapp.ResourceBundleStrLookup;
import at.iaik.commons.webapp.StrutsResourceBundleStrLookup;

/**
 * @author AT-TUG (Thomas Knall)
 */
public final class WebAppUtil {
	
	private static Logger log = Logger.getLogger(WebAppUtil.class);

   private static ResourceBundleStrLookup resourceBundleStrLookup = null;

   public static void cleanUpSession(HttpSession httpSession) {
      httpSession.removeAttribute(Constants.SESS_SUBJECT_ATTRIBUTES);
		log.debug("Cleaning up session.");
	}
   
   public static String calculateDigestFromEIdentifier(String eIdentifier) throws NoSuchAlgorithmException, UnsupportedEncodingException {
      MiscUtil.assertNotNull(eIdentifier, "eIdentifier");
      log.debug("Calculating message digest (" + Configuration.getMoodleProperty("moodle.hash.algorithm.username") + ") from eIdentifier.");
      MessageDigest md = MessageDigest.getInstance(Configuration.getMoodleProperty("moodle.hash.algorithm.username")); 
      byte[] digest = md.digest(eIdentifier.getBytes("UTF-8"));
      return (Util.toString(digest, "").toLowerCase());
   }

	public static String saveGetMessage(String key, ResourceBundle bundle) {
		String result = null;
		try {
			result = bundle.getString(key);
		} catch (MissingResourceException e) {
			log.debug(e.getMessage());
		}
		return result;
	}

   public static String replaceI18N(String text, HttpServletRequest request) {
      if (MiscUtil.isEmpty(text)) {
         return text;
      }
      if (resourceBundleStrLookup == null) {
         resourceBundleStrLookup = new ResourceBundleStrLookup(Configuration.getResourceBundle());
      }
      StrSubstitutor strSubst = new StrSubstitutor(request != null ? new StrutsResourceBundleStrLookup(request) : resourceBundleStrLookup, "#{", "}", '#');
      String replaced = strSubst.replace(text); 
      log.trace("Replacement: \"" + text + "\" -> \"" + replaced + "\"");
      return replaced;
   }

	private WebAppUtil() {
	}
	
	public static void addServiceHeader(HttpServletResponse response) {
      String storkServiceHeaderName = Configuration.getInternalProperty("eid-connector.httpheader.service");
      String storkServiceHeaderValue = Configuration.getInternalProperty("eid-connector.httpheader.service.value");
      if (MiscUtil.areAllNotEmpty(storkServiceHeaderName, storkServiceHeaderValue)) {
         log.debug("Adding service recognition header \"" + storkServiceHeaderName + ": " + storkServiceHeaderValue + "\".");
         response.setHeader(storkServiceHeaderName, storkServiceHeaderValue);
      } else {
         log.debug("Service recognition header not set due to missing configuration entries.");
      }
	}
	
}
