/*
 * Copyright 2010 Graz University of Technology
 *
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * http://www.osor.eu/eupl/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 */
package at.gv.egiz.test;

import iaik.utils.Base64InputStream;

import java.io.ByteArrayInputStream;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.text.ParseException;
import java.util.Date;

import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.log4j.Logger;
import org.opensaml.xml.io.Unmarshaller;
import org.opensaml.xml.io.UnmarshallerFactory;
import org.opensaml.xml.io.UnmarshallingException;
import org.opensaml.xml.parse.BasicParserPool;
import org.opensaml.xml.parse.XMLParserException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import at.gv.egiz.moodle.eidconnector.core.config.Configuration;
import at.gv.egiz.moodle.eidconnector.data.StatisticLog;
import at.gv.egiz.moodle.eidconnector.logging.StatisticLogger;
import at.gv.egiz.moodle.eidconnector.logging.impl.SimpleStatisticLogger;
import at.iaik.commons.util.DateTimeUtil;
import at.iaik.commons.util.HibernateUtil;
import eu.stork.mw.messages.saml.STORKResponse;
import eu.stork.vidp.messages.common.STORKBootstrap;


/**
 * @author AT-TUG (Thomas Knall)
 */
public final class MiscTest {
   
   private MiscTest() {
   }
   
   private static Logger log = Logger.getLogger(MiscTest.class);

   final static String EXAMPLE_RAW_RESPONSE = 
      "PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz48c2FtbDJwOlJlc3BvbnNlIHhtbG5z" +
      "OnNhbWwycD0idXJuOm9hc2lzOm5hbWVzOnRjOlNBTUw6Mi4wOnByb3RvY29sIiB4bWxuczpkcz0iaHR0" +
      "cDovL3d3dy53My5vcmcvMjAwMC8wOS94bWxkc2lnIyIgeG1sbnM6c2FtbDI9InVybjpvYXNpczpuYW1l" +
      "czp0YzpTQU1MOjIuMDphc3NlcnRpb24iIHhtbG5zOnN0b3JrPSJ1cm46ZXU6c3Rvcms6bmFtZXM6dGM6" +
      "U1RPUks6MS4wOmFzc2VydGlvbiIgeG1sbnM6c3RvcmtwPSJ1cm46ZXU6c3Rvcms6bmFtZXM6dGM6U1RP" +
      "Uks6MS4wOnByb3RvY29sIiBDb25zZW50PSJ1cm46b2FzaXM6bmFtZXM6dGM6U0FNTDoyLjA6Y29uc2Vu" +
      "dDpvYnRhaW5lZCIgRGVzdGluYXRpb249Imh0dHA6Ly9wZXBzLmluZHJhLmVzL1BFUFMvQ29sbGVhZ3Vl" +
      "UmVzcG9uc2U7anNlc3Npb25pZD04OTE5NUUyQ0U2NDQ5RkMwRUIyRTA5QTEyQTQ0NjUyRiIgSUQ9Il9i" +
      "ODQzMmI2YzE1NTllZTFiODVjODVjZGY5ZTNmMzVhZSIgSW5SZXNwb25zZVRvPSJfNWFlOGFiNWM3MTMw" +
      "YzJlOTFhNjFhMGY4OGY2MWMyZTkiIElzc3VlSW5zdGFudD0iMjAxMC0wNy0wMVQxMToyNjowMS42MjVa" +
      "IiBWZXJzaW9uPSIyLjAiPjxzYW1sMjpJc3N1ZXIgRm9ybWF0PSJ1cm46b2FzaXM6bmFtZXM6dGM6U0FN" +
      "TDoyLjA6bmFtZWlkLWZvcm1hdDplbnRpdHkiPmh0dHA6Ly9DLVBFUFMuZ292Lnh4PC9zYW1sMjpJc3N1" +
      "ZXI%2BPGRzOlNpZ25hdHVyZSB4bWxuczpkcz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC8wOS94bWxkc2" +
      "lnIyI%2BCjxkczpTaWduZWRJbmZvPgo8ZHM6Q2Fub25pY2FsaXphdGlvbk1ldGhvZCBBbGdvcml0aG09" +
      "Imh0dHA6Ly93d3cudzMub3JnLzIwMDEvMTAveG1sLWV4Yy1jMTRuIyIvPgo8ZHM6U2lnbmF0dXJlTWV0" +
      "aG9kIEFsZ29yaXRobT0iaHR0cDovL3d3dy53My5vcmcvMjAwMC8wOS94bWxkc2lnI3JzYS1zaGExIi8%" +
      "2BCjxkczpSZWZlcmVuY2UgVVJJPSIjX2I4NDMyYjZjMTU1OWVlMWI4NWM4NWNkZjllM2YzNWFlIj4KPG" +
      "RzOlRyYW5zZm9ybXM%2BCjxkczpUcmFuc2Zvcm0gQWxnb3JpdGhtPSJodHRwOi8vd3d3LnczLm9yZy8y" +
      "MDAwLzA5L3htbGRzaWcjZW52ZWxvcGVkLXNpZ25hdHVyZSIvPgo8ZHM6VHJhbnNmb3JtIEFsZ29yaXRo" +
      "bT0iaHR0cDovL3d3dy53My5vcmcvMjAwMS8xMC94bWwtZXhjLWMxNG4jIj48ZWM6SW5jbHVzaXZlTmFt" +
      "ZXNwYWNlcyB4bWxuczplYz0iaHR0cDovL3d3dy53My5vcmcvMjAwMS8xMC94bWwtZXhjLWMxNG4jIiBQ" +
      "cmVmaXhMaXN0PSJkcyBzYW1sMiBzYW1sMnAgc3Rvcmsgc3RvcmtwIHhzIi8%2BPC9kczpUcmFuc2Zvcm" +
      "0%2BCjwvZHM6VHJhbnNmb3Jtcz4KPGRzOkRpZ2VzdE1ldGhvZCBBbGdvcml0aG09Imh0dHA6Ly93d3cu" +
      "dzMub3JnLzIwMDAvMDkveG1sZHNpZyNzaGExIi8%2BCjxkczpEaWdlc3RWYWx1ZT4rSlg1b29yQTBxYU" +
      "U2TnRLTGNHcUl1dEdYWE09PC9kczpEaWdlc3RWYWx1ZT4KPC9kczpSZWZlcmVuY2U%2BCjwvZHM6U2ln" +
      "bmVkSW5mbz4KPGRzOlNpZ25hdHVyZVZhbHVlPgpJK1hBTERQWkFRNEsxRC84M21pWUVKMTVLTmRWckZF" +
      "bWordStnUlZvaURMUjY3NTE3VlBTbDRkVnl4US9TQWFmM0psZGIydkVFR1p3Ckgvc0UwUUpsMmM4WU9T" +
      "Ky9HeTVQMnZMcVE5dGZ2ZC9OZzNHY21xdmEwOWJrbzRZTE1uWHRNNnl0TzZ3eHlCL3Q2RDBEWkk2aU93" +
      "WDkKQVRVUVYxdWNSN3Rpd0NORVhQRFpOZU1kdGZ3eWhIWGhsZXJYRVhtK0pkUy9LMmErQkhaNHJKamVm" +
      "UGpTRlpHU3dMK0tvY0c3OFdzWQp0MDdMcEpQckZyaHNwalhiZUE0QnZ1ZUJzakdTYkVoTEVmM2JTa3F5" +
      "ZU0zR1VaajFMTmJYWVZoS3JGZEZ1czYwZHJnY0pINUZpaHVFCkNubjRPWHlJdm0rd1E3N2xGR1JEWDhE" +
      "M1RsMTVhUmx2d0RFZGhnPT0KPC9kczpTaWduYXR1cmVWYWx1ZT4KPGRzOktleUluZm8%2BPGRzOlg1MD" +
      "lEYXRhPjxkczpYNTA5Q2VydGlmaWNhdGU%2BTUlJRFJUQ0NBaTBDQkV1b25yTXdEUVlKS29aSWh2Y05B" +
      "UUVGQlFBd1p6RUxNQWtHQTFVRUJoTUNSVk14RGpBTUJnTlZCQWdNQlZOdwpZV2x1TVE4d0RRWURWUVFI" +
      "REFaTllXUnlhV1F4RGpBTUJnTlZCQW9NQlVsdVpISmhNU2N3SlFZRFZRUUREQjVTWldabGNtVnVZMlZR" +
      "ClJWQlRJRVJsYlc4Z1EyVnlkR2xtYVdOaGRHVXdIaGNOTVRBd016SXpNVEExTnpVMVdoY05NVEF3TmpB" +
      "eE1UQTFOelUxV2pCbk1Rc3cKQ1FZRFZRUUdFd0pGVXpFT01Bd0dBMVVFQ0F3RlUzQmhhVzR4RHpBTkJn" +
      "TlZCQWNNQmsxaFpISnBaREVPTUF3R0ExVUVDZ3dGU1c1awpjbUV4SnpBbEJnTlZCQU1NSGxKbFptVnla" +
      "VzVqWlZCRlVGTWdSR1Z0YnlCRFpYSjBhV1pwWTJGMFpUQ0NBU0l3RFFZSktvWklodmNOCkFRRUJCUUFE" +
      "Z2dFUEFEQ0NBUW9DZ2dFQkFJN3ByQTVaZnhmSHp3WDlkbnhhU1hUR3U5N2RhQ0tGMmMyZmRucHFydTVC" +
      "YnNmN1Q2RWYKZVFQSFZlSEFIZUdDVExLMU8zWDNmM21aYlFONktldHpVNlRadUhpQUMwVmdsR0JyNTFD" +
      "SXBSWmg5MzQ3bTdYNmVjNVpWdXdsbzkvRQpqcGVIMG8rQVJvc2pmYllYd2NnV2Z1MGw4Mk1EZ3FKWEVr" +
      "UVQxWHRIWHlGT1pJcVFnZVhoT3p0a0tLdTEvWjJCdVFhanNWbGRjL2hLCk1NRFpmdlJycWZNN1BJK0Zz" +
      "UlVUcXJNYmR2NlhWVWZRVklOUWpielg4dE1MSzY3VG45VmhwSlZHQmFKUExyNDJOQndPOGRVZUs0dm0K" +
      "SnJmTUlsZWhjZ0hBWlBZZ0ZFQVJHbTdETU53VW9hZ3dzT25pSGFSMk1ZMXFnU0wvYlVCbmpONXFucEV5" +
      "ZHdzQ0F3RUFBVEFOQmdrcQpoa2lHOXcwQkFRVUZBQU9DQVFFQUNoRjJHTkJucXdqR3RDOGdSa3E4b2ZN" +
      "Umtvd0NtT2hFREpWYXM3MDZZSnVVWFlXUEVjOUpYdEgxClltUnc1dmQ5TmIvRHBMdkNqMHNkMTdIanJU" +
      "dEhkMDlQMUlQRm1zalJXSFJjeXl4R3NmTStFUGYzc0l3WjVuRm0wMEpkdVJnaXgvS2oKM09xK2Fmd2p6" +
      "WjhJRkY3dzNwSEo0WmVJSEFrOEh3Vi9YSHY4WnpJWGE0NGxSL1VQekhtaHJFK2RCOXRWTzlkQVZ1MWlL" +
      "UkxjQ0JTRQpnRVBtaXNYV25aS0x3OHQ0d3NaZnNPakNLVUhXbHBCOURpeXZWSlJUKzVyd2pITUhza2Er" +
      "R3dBcmc1ODNLT09maTRZemZRRktjdlhNCk02VVVMUnc0Z2xsQjRha2tqU1phZHBoWDVYZE1jWWdHbGE2" +
      "S0RMT3dnVXlScnZBdXRKQVdBbjlUL2c9PTwvZHM6WDUwOUNlcnRpZmljYXRlPjwvZHM6WDUwOURhdGE%" +
      "2BPC9kczpLZXlJbmZvPjwvZHM6U2lnbmF0dXJlPjxzYW1sMnA6U3RhdHVzPjxzYW1sMnA6U3RhdHVzQ2" +
      "9kZSBWYWx1ZT0idXJuOm9hc2lzOm5hbWVzOnRjOlNBTUw6Mi4wOnN0YXR1czpTdWNjZXNzIi8%2BPHNh" +
      "bWwycDpTdGF0dXNNZXNzYWdlPnVybjpvYXNpczpuYW1lczp0YzpTQU1MOjIuMDpzdGF0dXM6U3VjY2Vz" +
      "czwvc2FtbDJwOlN0YXR1c01lc3NhZ2U%2BPC9zYW1sMnA6U3RhdHVzPjxzYW1sMjpBc3NlcnRpb24gSU" +
      "Q9Il85MWM1YzM0ZjRjNDVlNTRlZmU1MzhlNzJjNmJmZWEzOSIgSXNzdWVJbnN0YW50PSIyMDEwLTA3LT" +
      "AxVDExOjI2OjAxLjYzMFoiIFZlcnNpb249IjIuMCI%2BPHNhbWwyOklzc3VlciBGb3JtYXQ9InVybjpv" +
      "YXNpczpuYW1lczp0YzpTQU1MOjIuMDpuYW1laWQtZm9ybWF0OmVudGl0eSI%2BaHR0cDovL0MtUEVQUy" +
      "5nb3YueHg8L3NhbWwyOklzc3Vlcj48c2FtbDI6U3ViamVjdD48c2FtbDI6TmFtZUlEIEZvcm1hdD0idX" +
      "JuOm9hc2lzOm5hbWVzOnRjOlNBTUw6Mi4wOm5hbWVpZC1mb3JtYXQ6dW5zcGVjaWZpZWQiIE5hbWVRdW" +
      "FsaWZpZXI9Imh0dHA6Ly9DLVBFUFMuZ292Lnh4Ij51cm46b2FzaXM6bmFtZXM6dGM6U0FNTDoyLjA6bm" +
      "FtZWlkLWZvcm1hdDp1bnNwZWNpZmllZDwvc2FtbDI6TmFtZUlEPjxzYW1sMjpTdWJqZWN0Q29uZmlybW" +
      "F0aW9uIE1ldGhvZD0idXJuOm9hc2lzOm5hbWVzOnRjOlNBTUw6Mi4wOmNtOmJlYXJlciI%2BPHNhbWwy" +
      "OlN1YmplY3RDb25maXJtYXRpb25EYXRhIEFkZHJlc3M9IjEyOS4yNy4xNTIuMTI2IiBJblJlc3BvbnNl" +
      "VG89Il81YWU4YWI1YzcxMzBjMmU5MWE2MWEwZjg4ZjYxYzJlOSIgTm90T25PckFmdGVyPSIyMDEwLTA3" +
      "LTAxVDExOjMxOjAxLjYyOVoiIFJlY2lwaWVudD0iaHR0cDovL3BlcHMuaW5kcmEuZXMvUEVQUy9Db2xs" +
      "ZWFndWVSZXNwb25zZTtqc2Vzc2lvbmlkPTg5MTk1RTJDRTY0NDlGQzBFQjJFMDlBMTJBNDQ2NTJGIi8%" +
      "2BPC9zYW1sMjpTdWJqZWN0Q29uZmlybWF0aW9uPjwvc2FtbDI6U3ViamVjdD48c2FtbDI6Q29uZGl0aW" +
      "9ucyBOb3RCZWZvcmU9IjIwMTAtMDctMDFUMTE6MjY6MDEuNjM0WiIgTm90T25PckFmdGVyPSIyMDEwLT" +
      "A3LTAxVDExOjMxOjAxLjYyOVoiPjxzYW1sMjpBdWRpZW5jZVJlc3RyaWN0aW9uPjxzYW1sMjpBdWRpZW" +
      "5jZT5odHRwOi8vUy1QRVBTLmdvdi54eDwvc2FtbDI6QXVkaWVuY2U%2BPC9zYW1sMjpBdWRpZW5jZVJl" +
      "c3RyaWN0aW9uPjxzYW1sMjpPbmVUaW1lVXNlLz48L3NhbWwyOkNvbmRpdGlvbnM%2BPHNhbWwyOkF1dG" +
      "huU3RhdGVtZW50IEF1dGhuSW5zdGFudD0iMjAxMC0wNy0wMVQxMToyNjowMS42MzRaIj48c2FtbDI6U3" +
      "ViamVjdExvY2FsaXR5IEFkZHJlc3M9IjEyOS4yNy4xNTIuMTI2Ii8%2BPHNhbWwyOkF1dGhuQ29udGV4" +
      "dD48c2FtbDI6QXV0aG5Db250ZXh0RGVjbC8%2BPC9zYW1sMjpBdXRobkNvbnRleHQ%2BPC9zYW1sMjpB" +
      "dXRoblN0YXRlbWVudD48c2FtbDI6QXR0cmlidXRlU3RhdGVtZW50PjxzYW1sMjpBdHRyaWJ1dGUgTmFt" +
      "ZT0iaHR0cDovL3d3dy5zdG9yay5nb3YuZXUvMS4wL2VJZGVudGlmaWVyIiBOYW1lRm9ybWF0PSJ1cm46" +
      "b2FzaXM6bmFtZXM6dGM6U0FNTDoyLjA6YXR0cm5hbWUtZm9ybWF0OnVyaSIgc3Rvcms6QXR0cmlidXRl" +
      "U3RhdHVzPSJBdmFpbGFibGUiPjxzYW1sMjpBdHRyaWJ1dGVWYWx1ZSB4bWxuczp4cz0iaHR0cDovL3d3" +
      "dy53My5vcmcvMjAwMS9YTUxTY2hlbWEiIHhtbG5zOnhzaT0iaHR0cDovL3d3dy53My5vcmcvMjAwMS9Y" +
      "TUxTY2hlbWEtaW5zdGFuY2UiIHhzaTp0eXBlPSJ4czpzdHJpbmciPlJGL0VTLzEyMzQ1Njc4OTA8L3Nh" +
      "bWwyOkF0dHJpYnV0ZVZhbHVlPjwvc2FtbDI6QXR0cmlidXRlPjxzYW1sMjpBdHRyaWJ1dGUgTmFtZT0i" +
      "aHR0cDovL3d3dy5zdG9yay5nb3YuZXUvMS4wL2NpdGl6ZW5RQUFsZXZlbCIgTmFtZUZvcm1hdD0idXJu" +
      "Om9hc2lzOm5hbWVzOnRjOlNBTUw6Mi4wOmF0dHJuYW1lLWZvcm1hdDp1cmkiIHN0b3JrOkF0dHJpYnV0" +
      "ZVN0YXR1cz0iQXZhaWxhYmxlIj48c2FtbDI6QXR0cmlidXRlVmFsdWUgeG1sbnM6eHM9Imh0dHA6Ly93" +
      "d3cudzMub3JnLzIwMDEvWE1MU2NoZW1hIiB4bWxuczp4c2k9Imh0dHA6Ly93d3cudzMub3JnLzIwMDEv" +
      "WE1MU2NoZW1hLWluc3RhbmNlIiB4c2k6dHlwZT0ieHM6c3RyaW5nIj40PC9zYW1sMjpBdHRyaWJ1dGVW" +
      "YWx1ZT48L3NhbWwyOkF0dHJpYnV0ZT48c2FtbDI6QXR0cmlidXRlIE5hbWU9Imh0dHA6Ly93d3cuc3Rv" +
      "cmsuZ292LmV1LzEuMC9hZ2UiIE5hbWVGb3JtYXQ9InVybjpvYXNpczpuYW1lczp0YzpTQU1MOjIuMDph" +
      "dHRybmFtZS1mb3JtYXQ6dXJpIiBzdG9yazpBdHRyaWJ1dGVTdGF0dXM9IkF2YWlsYWJsZSI%2BPHNhbW" +
      "wyOkF0dHJpYnV0ZVZhbHVlIHhtbG5zOnhzPSJodHRwOi8vd3d3LnczLm9yZy8yMDAxL1hNTFNjaGVtYS" +
      "IgeG1sbnM6eHNpPSJodHRwOi8vd3d3LnczLm9yZy8yMDAxL1hNTFNjaGVtYS1pbnN0YW5jZSIgeHNpOn" +
      "R5cGU9InhzOnN0cmluZyI%2BMTEwPC9zYW1sMjpBdHRyaWJ1dGVWYWx1ZT48L3NhbWwyOkF0dHJpYnV0" +
      "ZT48L3NhbWwyOkF0dHJpYnV0ZVN0YXRlbWVudD48L3NhbWwyOkFzc2VydGlvbj48L3NhbWwycDpSZXNw" +
      "b25zZT4%3D";

   public static void test1() throws UnmarshallingException, org.opensaml.xml.ConfigurationException, UnsupportedEncodingException, XMLParserException {
      // Initialization is automatically done by the webapplication
      STORKBootstrap.bootstrap();
      
      
      // Get response
//      String urlAndBase64EncodedPEPSResponse = request.getParameter("SAMLResponse");
      String urlAndBase64EncodedPEPSResponse = EXAMPLE_RAW_RESPONSE;
      
      // URL decode
      String base64EncodedPEPSResponse = URLDecoder.decode(urlAndBase64EncodedPEPSResponse, "UTF-8");
      
      // Base64 decode
      Base64InputStream base64InputStream = new Base64InputStream(new ByteArrayInputStream(base64EncodedPEPSResponse.getBytes("UTF-8")));
      
      // Get parser pool manager
      BasicParserPool ppMgr = new BasicParserPool();
      ppMgr.setNamespaceAware(true);
      
      Document responseDoc = ppMgr.parse(base64InputStream);
      Element responseRoot = responseDoc.getDocumentElement();

      // Get apropriate unmarshaller
      UnmarshallerFactory unmarshallerFactory = org.opensaml.xml.Configuration.getUnmarshallerFactory();
      Unmarshaller unmarshaller = unmarshallerFactory.getUnmarshaller(responseRoot);

      // Unmarshall using the document root element, an EntitiesDescriptor in this case
      STORKResponse samlResponse = (STORKResponse) unmarshaller.unmarshall(responseRoot);

      // SAML response is now parsed
      System.out.println(samlResponse);
   }
   
   public static void testlogger() throws ParseException {
      StatisticLog  sl;
      
      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-07T12:27:16.027Z"),
               "MOA-ID-AT",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "iEt9+W/ZXpyoU1o/BpxHORVGSkw=",
               "AT",
               4,
               32,
               "https://www.stork-kids.at/bkuonline/https-security-layer-request",
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);
      
      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-07T12:27:41.454Z"),
               "MOA-ID-AT",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "iEt9+W/ZXpyoU1o/BpxHORVGSkw=",
               "AT",
               4,
               32,
               "https://127.0.0.1:3496/https-security-layer-request",
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);
      
      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-07T12:28:40.005Z"),
               "MOA-ID-AT",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "iEt9+W/ZXpyoU1o/BpxHORVGSkw=",
               "AT",
               4,
               32,
               "https://www.a-trust.at/mobile/https-security-layer-request/default.aspx",
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);
      
      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-07T12:29:05.561Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-08T08:50:10.368Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "C4iXzu6+DofCN6TalVo48+CCLbM=",
               null,
               4,
               27,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-08T11:32:59.399Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "7A1nslkCDjoFxs8EXQUCdpz+obg=",
               null,
               4,
               42,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-08T17:10:58.149Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "0cRO96dkjv6VEit9AaQza4hD2uo=",
               null,
               4,
               41,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-08T17:13:32.946Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "0cRO96dkjv6VEit9AaQza4hD2uo=",
               null,
               4,
               41,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-08T22:43:51.165Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "AQxf6ZxJ8M8WlrX462Umjd8zXws=",
               null,
               4,
               15,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-08T23:12:57.962Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "AQxf6ZxJ8M8WlrX462Umjd8zXws=",
               null,
               4,
               15,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-09T17:57:06.853Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "AQxf6ZxJ8M8WlrX462Umjd8zXws=",
               null,
               4,
               15,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-09T18:49:49.962Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "AQxf6ZxJ8M8WlrX462Umjd8zXws=",
               null,
               4,
               15,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-09T20:30:53.165Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T11:05:02.665Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T11:28:14.790Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "sKnPsoB9hX/PEVS5ZjvTrN7FIjw=",
               null,
               4,
               50,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T12:16:25.524Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "UH8GdWfK0CHrN7mHA4FBF4BIVOs=",
               null,
               4,
               16,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T12:19:26.696Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "UH8GdWfK0CHrN7mHA4FBF4BIVOs=",
               null,
               4,
               16,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T12:21:42.134Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "UH8GdWfK0CHrN7mHA4FBF4BIVOs=",
               null,
               4,
               16,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T12:23:13.353Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T13:05:09.681Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "sKnPsoB9hX/PEVS5ZjvTrN7FIjw=",
               null,
               4,
               50,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T13:09:53.587Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "AQxf6ZxJ8M8WlrX462Umjd8zXws=",
               null,
               4,
               15,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T14:13:30.024Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "UH8GdWfK0CHrN7mHA4FBF4BIVOs=",
               null,
               4,
               16,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T14:28:50.259Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T14:38:24.946Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "C4iXzu6+DofCN6TalVo48+CCLbM=",
               null,
               4,
               27,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T14:58:48.087Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "UH8GdWfK0CHrN7mHA4FBF4BIVOs=",
               null,
               4,
               16,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-10T15:12:04.774Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "sKnPsoB9hX/PEVS5ZjvTrN7FIjw=",
               null,
               4,
               50,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);


      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-13T07:11:24.868Z"),
               "MOA-ID-AT",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "iEt9+W/ZXpyoU1o/BpxHORVGSkw=",
               "AT",
               4,
               32,
               "https://127.0.0.1:3496/https-security-layer-request",
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-13T14:53:43.561Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-14T07:27:23.677Z"),
               "MOA-ID-AT",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "iEt9+W/ZXpyoU1o/BpxHORVGSkw=",
               "AT",
               4,
               32,
               "https://www.stork-kids.at/bkuonline/https-security-layer-request",
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-14T07:32:22.602Z"),
               "MOA-ID-AT",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "iEt9+W/ZXpyoU1o/BpxHORVGSkw=",
               "AT",
               4,
               32,
               "https://www.stork-kids.at/bkuonline/https-security-layer-request",
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-14T08:19:40.648Z"),
               "MOA-ID-AT",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "iEt9+W/ZXpyoU1o/BpxHORVGSkw=",
               "AT",
               4,
               32,
               "https://www.a-trust.at/mobile/https-security-layer-request/default.aspx",
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-14T13:34:10.050Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-14T14:30:47.455Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);

      sl = new StatisticLog(
               DateTimeUtil.parseXMLDateTimeString("2010-09-14T14:43:20.629Z"),
               "stork",
               "https://www.stork-kids.at/moodle19/auth/stork/index.php",
               "rm7/fOD3GPpcfJFZaIpjhsMHEcY=",
               null,
               4,
               35,
               null,
               "urn:publicid:gv.at:wbpk+FN+468924i");
      HibernateUtil.saveOrUpdate(Configuration.HBM_NAME_EID_CONNECTOR, sl);
      
   }
   
   public static void main(String[] args) {

      try {


         // new CSVStatisticLogger().log(new Date(), "assertionIssuerId", "SP,ID", null, "A\"T", 6, 18, "xxx", 17, new Date());
         Configuration.init("D:/dev/proj/Moodle-eID-Connector-Impl/impl/src/main/resources/application_config.xml");
         
         StatisticLogger sl = new SimpleStatisticLogger();
         sl.log(new Date(), "STORK", "https://www.stork-kids.at/moodle19/auth/stork/index.php", "iEt9+W/ZXpyoU1o/BpxHORVGSkw=", "IS", 4, 18);
         
         
      } catch (Throwable e) {
         String stackTrace = ExceptionUtils.getFullStackTrace(e);
         System.err.println(stackTrace);
      }

   }

}
